@@ -110,7 +110,7 @@ typedef enum {
 	CTC_SeqAfter = 0x8000,
 	/* The following 8 are reserved for %0 to %7 (in no particular order) */
 	/* Be careful with changing these values (and also CTC_EndOfInput) because in
-	   pattern_compile_expression they are stored in a unsigned int after cutting of the
+	   pattern_compile_expression they are stored in a unsigned int after cutting off the
 	   16 least significant bits. */
 	CTC_UserDefined1 = 0x10000,
 	CTC_UserDefined2 = 0x20000,
@@ -124,7 +124,7 @@ typedef enum {
 	CTC_EmpMatch = 0x2000000,	 // only used in TranslationTableRule->before and
 								 // TranslationTableRule->after
 	CTC_MidEndNumericMode = 0x4000000,
-	/* At least 37 more bits available in a unsigned long long (at least 64 bits). Used
+	/* At least 37 more bits available in an unsigned long long (at least 64 bits). Used
 	   for custom attributes 9 to 45. These need to be the last values of the enum. */
 	CTC_UserDefined9 = 0x8000000,
 	CTC_UserDefined10 = 0x10000000,
@@ -486,7 +486,7 @@ typedef struct { /* translation table */
 	TranslationTableOffset dots[HASHNUM];		/** Dot definitions */
 	TranslationTableOffset forPassRules[MAXPASS + 1];
 	TranslationTableOffset backPassRules[MAXPASS + 1];
-	TranslationTableOffset forRules[HASHNUM];  /** chains of forward rules */
+	TranslationTableOffset forRules[HASHNUM];  /** Chains of forward rules */
 	TranslationTableOffset backRules[HASHNUM]; /** Chains of backward rules */
 	TranslationTableData ruleArea[1]; /** Space for storing all rules and values */
 } TranslationTableHeader;
